@@ -1,37 +1,37 @@
 package Net::DNS;
 #
-# $Id: DNS.pm,v 2.105 2004/02/10 00:42:30 ctriv Exp $
+# $Id: DNS.pm,v 2.113 2004/05/06 19:11:23 ctriv Exp $
 #
 use strict;
 use vars qw(
-	$HAVE_XS
-	$VERSION
-	$DNSSEC
-	@ISA
-	@EXPORT
-	%typesbyname
-	%typesbyval
-	%qtypesbyname
-	%qtypesbyval
-	%metatypesbyname
-	%metatypesbyval
-	%classesbyname
-	%classesbyval
-	%opcodesbyname
-	%opcodesbyval
-	%rcodesbyname
-	%rcodesbyval
+    $HAVE_XS
+    $VERSION
+    $DNSSEC
+    @ISA
+    @EXPORT
+    %typesbyname
+    %typesbyval
+    %qtypesbyname
+    %qtypesbyval
+    %metatypesbyname
+    %metatypesbyval
+    %classesbyname
+    %classesbyval
+    %opcodesbyname
+    %opcodesbyval
+    %rcodesbyname
+    %rcodesbyval
 );
 
 
 
 BEGIN {
-	require DynaLoader;
-	require Exporter;
-	
-	@ISA     = qw(Exporter DynaLoader);
-	$VERSION = '0.45_01';
-	$HAVE_XS = eval { __PACKAGE__->bootstrap(); 1 } ? 1 : 0;
+    require DynaLoader;
+    require Exporter;
+    
+    @ISA     = qw(Exporter DynaLoader);
+    $VERSION = '0.47_01';
+    $HAVE_XS = eval { __PACKAGE__->bootstrap(); 1 } ? 1 : 0;
 }
 
 use Net::DNS::Resolver;
@@ -42,7 +42,7 @@ use Net::DNS::Question;
 use Net::DNS::RR;
 
 BEGIN {
-	$DNSSEC = eval { require Net::DNS::RR::SIG; 1 } ? 1 : 0;
+    $DNSSEC = eval { require Net::DNS::RR::SIG; 1 } ? 1 : 0;
 }
  
 
@@ -58,65 +58,66 @@ BEGIN {
 # functions, see below.
 
 %typesbyname = (
- 	'SIGZERO'   => 0,       # RFC2931 consider this a pseudo type
-	'A'			=> 1,		# RFC 1035, Section 3.4.1
-	'NS'		=> 2,		# RFC 1035, Section 3.3.11
-	'MD'		=> 3,		# RFC 1035, Section 3.3.4 (obsolete)
-	'MF'		=> 4,		# RFC 1035, Section 3.3.5 (obsolete)
-	'CNAME'		=> 5,		# RFC 1035, Section 3.3.1
-	'SOA'		=> 6,		# RFC 1035, Section 3.3.13
-	'MB'		=> 7,		# RFC 1035, Section 3.3.3
-	'MG'		=> 8,		# RFC 1035, Section 3.3.6
-	'MR'		=> 9,		# RFC 1035, Section 3.3.8
-	'NULL'		=> 10,		# RFC 1035, Section 3.3.10
-	'WKS'		=> 11,		# RFC 1035, Section 3.4.2 (deprecated)
-	'PTR'		=> 12,		# RFC 1035, Section 3.3.12
-	'HINFO'		=> 13,		# RFC 1035, Section 3.3.2
-	'MINFO' 	=> 14,		# RFC 1035, Section 3.3.7
-	'MX'		=> 15,		# RFC 1035, Section 3.3.9
-	'TXT'		=> 16,		# RFC 1035, Section 3.3.14
-	'RP'		=> 17,		# RFC 1183, Section 2.2
-	'AFSDB'		=> 18,		# RFC 1183, Section 1
-	'X25'		=> 19,		# RFC 1183, Section 3.1
-	'ISDN'		=> 20,		# RFC 1183, Section 3.2
-	'RT'		=> 21,		# RFC 1183, Section 3.3
-	'NSAP'		=> 22,		# RFC 1706, Section 5
-	'NSAP_PTR'	=> 23,		# RFC 1348 (obsolete)
-	# The following 2 RRs are impemented in Net::DNS::SEC
- 	'SIG'		=> 24,		# RFC 2535, Section 4.1
- 	'KEY'		=> 25,		# RFC 2535, Section 3.1
- 	'PX'		=> 26,		# RFC 2163,
-	'GPOS'		=> 27,		# RFC 1712 (obsolete)
-	'AAAA'		=> 28,		# RFC 1886, Section 2.1
-	'LOC'		=> 29,		# RFC 1876
-	# The following RR is impemented in Net::DNS::SEC
-	'NXT'		=> 30,		# RFC 2535, Section 5.2
-	'EID'		=> 31,		# draft-ietf-nimrod-dns-xx.txt
-	'NIMLOC'	=> 32,		# draft-ietf-nimrod-dns-xx.txt
-	'SRV'		=> 33,		# RFC 2052
-	'ATMA'		=> 34,		# ???
-	'NAPTR'		=> 35,		# RFC 2168
-	'KX'		=> 36,		# RFC 2230
- 	'CERT'		=> 37,		# RFC 2538
-	'DNAME'		=> 39,		# RFC 2672
-	'OPT'  		=> 41,		# RFC 2671
-	# The following 4 RRs are impemented in Net::DNS::SEC
-	# Aug 2003: These RRs will be published as RFCs shortly 
-	'DS'		=> 43,		# draft-ietf-dnsext-delegation-signer
-	'RRSIG'		=> 46,		# draft-ietf-dnsext-dnssec-2535typecode-change
-	'NSEC'		=> 47,		# draft-ietf-dnsext-dnssec-2535typecode-change
-	'DNSKEY'	=> 48,		# draft-ietf-dnsext-dnssec-2535typecode-change
-	'UINFO'		=> 100,		# non-standard
-	'UID'		=> 101,		# non-standard
-	'GID'		=> 102,		# non-standard
-	'UNSPEC'	=> 103,		# non-standard
-	'TKEY'		=> 249,		# RFC 2930
-	'TSIG'		=> 250,		# RFC 2931
-	'IXFR'		=> 251,		# RFC 1995
-	'AXFR'		=> 252,		# RFC 1035
-	'MAILB'		=> 253,		# RFC 1035 (MB, MG, MR)
-	'MAILA'		=> 254,		# RFC 1035 (obsolete - see MX)
-	'ANY'		=> 255,		# RFC 1035
+    'SIGZERO'   => 0,       # RFC2931 consider this a pseudo type
+    'A'         => 1,       # RFC 1035, Section 3.4.1
+    'NS'        => 2,       # RFC 1035, Section 3.3.11
+    'MD'        => 3,       # RFC 1035, Section 3.3.4 (obsolete)
+    'MF'        => 4,       # RFC 1035, Section 3.3.5 (obsolete)
+    'CNAME'     => 5,       # RFC 1035, Section 3.3.1
+    'SOA'       => 6,       # RFC 1035, Section 3.3.13
+    'MB'        => 7,       # RFC 1035, Section 3.3.3
+    'MG'        => 8,       # RFC 1035, Section 3.3.6
+    'MR'        => 9,       # RFC 1035, Section 3.3.8
+    'NULL'      => 10,      # RFC 1035, Section 3.3.10
+    'WKS'       => 11,      # RFC 1035, Section 3.4.2 (deprecated)
+    'PTR'       => 12,      # RFC 1035, Section 3.3.12
+    'HINFO'     => 13,      # RFC 1035, Section 3.3.2
+    'MINFO'     => 14,      # RFC 1035, Section 3.3.7
+    'MX'        => 15,      # RFC 1035, Section 3.3.9
+    'TXT'       => 16,      # RFC 1035, Section 3.3.14
+    'RP'        => 17,      # RFC 1183, Section 2.2
+    'AFSDB'     => 18,      # RFC 1183, Section 1
+    'X25'       => 19,      # RFC 1183, Section 3.1
+    'ISDN'      => 20,      # RFC 1183, Section 3.2
+    'RT'        => 21,      # RFC 1183, Section 3.3
+    'NSAP'      => 22,      # RFC 1706, Section 5
+    'NSAP_PTR'  => 23,      # RFC 1348 (obsolete)
+    # The following 2 RRs are impemented in Net::DNS::SEC
+    'SIG'       => 24,      # RFC 2535, Section 4.1
+    'KEY'       => 25,      # RFC 2535, Section 3.1
+    'PX'        => 26,      # RFC 2163,
+    'GPOS'      => 27,      # RFC 1712 (obsolete)
+    'AAAA'      => 28,      # RFC 1886, Section 2.1
+    'LOC'       => 29,      # RFC 1876
+    # The following RR is impemented in Net::DNS::SEC
+    'NXT'       => 30,      # RFC 2535, Section 5.2
+    'EID'       => 31,      # draft-ietf-nimrod-dns-xx.txt
+    'NIMLOC'    => 32,      # draft-ietf-nimrod-dns-xx.txt
+    'SRV'       => 33,      # RFC 2052
+    'ATMA'      => 34,      # ???
+    'NAPTR'     => 35,      # RFC 2168
+    'KX'        => 36,      # RFC 2230
+    'CERT'      => 37,      # RFC 2538
+    'DNAME'     => 39,      # RFC 2672
+    'OPT'       => 41,      # RFC 2671
+    # The following 4 RRs are impemented in Net::DNS::SEC
+    # Aug 2003: These RRs will be published as RFCs shortly 
+    'DS'        => 43,      # draft-ietf-dnsext-delegation-signer
+    'SSHFP'     => 44,          # draft-ietf-secsh-dns (No RFC # yet at time of coding)
+    'RRSIG'     => 46,      # draft-ietf-dnsext-dnssec-2535typecode-change
+    'NSEC'      => 47,      # draft-ietf-dnsext-dnssec-2535typecode-change
+    'DNSKEY'    => 48,      # draft-ietf-dnsext-dnssec-2535typecode-change
+    'UINFO'     => 100,     # non-standard
+    'UID'       => 101,     # non-standard
+    'GID'       => 102,     # non-standard
+    'UNSPEC'    => 103,     # non-standard
+    'TKEY'      => 249,     # RFC 2930
+    'TSIG'      => 250,     # RFC 2931
+    'IXFR'      => 251,     # RFC 1995
+    'AXFR'      => 252,     # RFC 1035
+    'MAILB'     => 253,     # RFC 1035 (MB, MG, MR)
+    'MAILA'     => 254,     # RFC 1035 (obsolete - see MX)
+    'ANY'       => 255,     # RFC 1035
 );
 %typesbyval = reverse %typesbyname;
 
@@ -136,37 +137,37 @@ BEGIN {
 #
 
 sub typesbyname {
-	my $name = uc shift;
+    my $name = uc shift;
 
-	return $typesbyname{$name} if $typesbyname{$name};
-	
-	die "Net::DNS::typesbyval() argument is not TYPE### ($name)" unless 
-		$name =~ m/^\s*TYPE(\d+)\s*$/;  
-	
-	my $val = $1;
-	
-	die 'Net::DNS::typesbyval() argument larger than ' . 0xffff if $val > 0xffff;
-	
-	return $val;
+    return $typesbyname{$name} if $typesbyname{$name};
+
+    die "Net::DNS::typesbyname() argument ($name) is not TYPE###" unless 
+        $name =~ m/^\s*TYPE(\d+)\s*$/;  
+    
+    my $val = $1;
+    
+    die 'Net::DNS::typesbyname() argument larger than ' . 0xffff if $val > 0xffff;
+    
+    return $val;
 }
 
 
 
 sub typesbyval {
-	my $val = shift;
-	
-	die "Net::DNS::typesbyname() argument is not numeric ($val)" unless 
-		$val =~ m/^\s*\d+\s*$/;  
-	
-	$val =~ s/\s*//g; 
-	$val =~ s/^0*//; 
-	
-	return $typesbyval{$val} if $typesbyval{$val};
-	
-	die 'Net::DNS::typesbyname() argument larger than '. 0xffff if 
-		$val > 0xffff;
-	
-	return "TYPE$val";
+    my $val = shift;
+    
+    die "Net::DNS::typesbyval() argument ($val) is not numeric" unless 
+        $val =~ m/^\s*\d+\s*$/;  
+    
+    $val =~ s/\s*//g; 
+    $val =~ s/^0*//; 
+    
+    return $typesbyval{$val} if $typesbyval{$val};
+    
+    die 'Net::DNS::typesbyval() argument larger than '. 0xffff if 
+        $val > 0xffff;
+    
+    return "TYPE$val";
 }
 
 
@@ -176,11 +177,11 @@ sub typesbyval {
 #
  
 %classesbyname = (
-	'IN'		=> 1,		# RFC 1035
-	'CH'		=> 3,		# RFC 1035
-	'HS'		=> 4,		# RFC 1035
-	'NONE'		=> 254,		# RFC 2136
-	'ANY'		=> 255,		# RFC 1035
+    'IN'        => 1,       # RFC 1035
+    'CH'        => 3,       # RFC 1035
+    'HS'        => 4,       # RFC 1035
+    'NONE'      => 254,     # RFC 2136
+    'ANY'       => 255,     # RFC 1035
 );
 %classesbyval = reverse %classesbyname;
 
@@ -193,35 +194,35 @@ sub typesbyval {
 # See typesbyval and typesbyname, these beasts have the same functionality
 
 sub classesbyname {
-	my $name = uc shift;
-	return $classesbyname{$name} if $classesbyname{$name};
-	
-	die "Net::DNS::classesbyval() argument is not CLASS### ($name)" unless 
-		$name =~ m/^\s*CLASS(\d+)\s*$/;
-	
-	my $val = $1;
-	
-	die 'Net::DNS::classesbyval() argument larger than '. 0xffff if $val > 0xffff;
-	
-	return $val;
+    my $name = uc shift;
+    return $classesbyname{$name} if $classesbyname{$name};
+    
+    die "Net::DNS::classesbyval() argument is not CLASS### ($name)" unless 
+        $name =~ m/^\s*CLASS(\d+)\s*$/;
+    
+    my $val = $1;
+    
+    die 'Net::DNS::classesbyval() argument larger than '. 0xffff if $val > 0xffff;
+    
+    return $val;
 }
 
 
 
 sub classesbyval {
-	my $val = shift;
-	
-	die "Net::DNS::classesbyname() argument is not numeric ($val)" unless 
-		$val=~/^\s*\d+\s*$/;
-	
-	$val =~ s/\s*//g;
-	$val =~ s/^0*//;
-	
-	return $classesbyval{$val} if $classesbyval{$val};
-	
-	die 'Net::DNS::classesbyname() argument larger than ' . 0xffff if $val > 0xffff;
-	
-	return "CLASS$val";
+    my $val = shift;
+    
+    die "Net::DNS::classesbyname() argument is not numeric ($val)" unless 
+        $val=~/^\s*\d+\s*$/;
+    
+    $val =~ s/\s*//g;
+    $val =~ s/^0*//;
+    
+    return $classesbyval{$val} if $classesbyval{$val};
+    
+    die 'Net::DNS::classesbyname() argument larger than ' . 0xffff if $val > 0xffff;
+    
+    return "CLASS$val";
 }
 
 
@@ -232,45 +233,45 @@ sub classesbyval {
 
 
 %qtypesbyname = (
-	'IXFR'   => 251,  # incremental transfer                [RFC1995]
-	'AXFR'   => 252,  # transfer of an entire zone          [RFC1035]
-	'MAILB'  => 253,  # mailbox-related RRs (MB, MG or MR)	 [RFC1035]
-	'MAILA'  => 254,  # mail agent RRs (Obsolete - see MX)	 [RFC1035]
-	'ANY'    => 255,  # all records		                 [RFC1035]
+    'IXFR'   => 251,  # incremental transfer                [RFC1995]
+    'AXFR'   => 252,  # transfer of an entire zone          [RFC1035]
+    'MAILB'  => 253,  # mailbox-related RRs (MB, MG or MR)   [RFC1035]
+    'MAILA'  => 254,  # mail agent RRs (Obsolete - see MX)   [RFC1035]
+    'ANY'    => 255,  # all records                      [RFC1035]
 );
 %qtypesbyval = reverse %qtypesbyname;
 
 
 %metatypesbyname = (
-	'TKEY'        => 249,    # Transaction Key   [RFC2930]
-	'TSIG'        => 250,    # Transaction Signature  [RFC2845]
-	'OPT'         => 41,     # RFC 2671
+    'TKEY'        => 249,    # Transaction Key   [RFC2930]
+    'TSIG'        => 250,    # Transaction Signature  [RFC2845]
+    'OPT'         => 41,     # RFC 2671
 );
 %metatypesbyval = reverse %metatypesbyname;
 
 
 %opcodesbyname = (
-	'QUERY'	       => 0,		# RFC 1035
-	'IQUERY'       => 1,		# RFC 1035
-	'STATUS'       => 2,		# RFC 1035
-	'NS_NOTIFY_OP' => 4,		# RFC 1996
-	'UPDATE'       => 5,		# RFC 2136
+    'QUERY'        => 0,        # RFC 1035
+    'IQUERY'       => 1,        # RFC 1035
+    'STATUS'       => 2,        # RFC 1035
+    'NS_NOTIFY_OP' => 4,        # RFC 1996
+    'UPDATE'       => 5,        # RFC 2136
 );
 %opcodesbyval = reverse %opcodesbyname;
 
 
 %rcodesbyname = (
-	'NOERROR'	=> 0,		# RFC 1035
-	'FORMERR'	=> 1,		# RFC 1035
-	'SERVFAIL'	=> 2,		# RFC 1035
-	'NXDOMAIN'	=> 3,		# RFC 1035
-	'NOTIMP'	=> 4,		# RFC 1035
-	'REFUSED'	=> 5,		# RFC 1035
-	'YXDOMAIN'	=> 6,		# RFC 2136
-	'YXRRSET'	=> 7,		# RFC 2136
-	'NXRRSET'	=> 8,		# RFC 2136
-	'NOTAUTH'	=> 9,		# RFC 2136
-	'NOTZONE'	=> 10,		# RFC 2136
+    'NOERROR'   => 0,       # RFC 1035
+    'FORMERR'   => 1,       # RFC 1035
+    'SERVFAIL'  => 2,       # RFC 1035
+    'NXDOMAIN'  => 3,       # RFC 1035
+    'NOTIMP'    => 4,       # RFC 1035
+    'REFUSED'   => 5,       # RFC 1035
+    'YXDOMAIN'  => 6,       # RFC 2136
+    'YXRRSET'   => 7,       # RFC 2136
+    'NXRRSET'   => 8,       # RFC 2136
+    'NOTAUTH'   => 9,       # RFC 2136
+    'NOTZONE'   => 10,      # RFC 2136
 );
 %rcodesbyval = reverse %rcodesbyname;
 
@@ -291,49 +292,49 @@ sub INT16SZ   () {   2; }
 #    my @mxes = mx('example.com', 'IN');
 #
 sub mx {
-	my $res = ref $_[0] ? shift : Net::DNS::Resolver->new;
+    my $res = ref $_[0] ? shift : Net::DNS::Resolver->new;
 
-	my ($name, $class) = @_;
-	$class ||= 'IN';
+    my ($name, $class) = @_;
+    $class ||= 'IN';
 
-	my $ans = $res->query($name, 'MX', $class) || return;
+    my $ans = $res->query($name, 'MX', $class) || return;
 
-	# This construct is best read backwords.
-	#
-	# First we take the answer secion of the packet.
-	# Then we take just the MX records from that list
-	# Then we sort the list by preference
-	# Then we return it.
-	# We do this into an array to force list context.
-	my @ret = sort { $a->preference <=> $b->preference } 
-	       	  grep { $_->type eq 'MX'} $ans->answer;
+    # This construct is best read backwords.
+    #
+    # First we take the answer secion of the packet.
+    # Then we take just the MX records from that list
+    # Then we sort the list by preference
+    # Then we return it.
+    # We do this into an array to force list context.
+    my @ret = sort { $a->preference <=> $b->preference } 
+              grep { $_->type eq 'MX'} $ans->answer;
 
 
-	return @ret;
+    return @ret;
 }
 
 sub yxrrset {
-	return Net::DNS::RR->new_from_string(shift, 'yxrrset');
+    return Net::DNS::RR->new_from_string(shift, 'yxrrset');
 }
 
 sub nxrrset {
-	return Net::DNS::RR->new_from_string(shift, 'nxrrset');
+    return Net::DNS::RR->new_from_string(shift, 'nxrrset');
 }
 
 sub yxdomain {
-	return Net::DNS::RR->new_from_string(shift, 'yxdomain');
+    return Net::DNS::RR->new_from_string(shift, 'yxdomain');
 }
 
 sub nxdomain {
-	return Net::DNS::RR->new_from_string(shift, 'nxdomain');
+    return Net::DNS::RR->new_from_string(shift, 'nxdomain');
 }
 
 sub rr_add {
-	return Net::DNS::RR->new_from_string(shift, 'rr_add');
+    return Net::DNS::RR->new_from_string(shift, 'rr_add');
 }
 
 sub rr_del {
-	return Net::DNS::RR->new_from_string(shift, 'rr_del');
+    return Net::DNS::RR->new_from_string(shift, 'rr_del');
 }
 
 1;
@@ -665,9 +666,9 @@ has arrived.
               $packet->print;
               $bgsock = undef;
           }
-	      # Check for the other sockets.
-	      $sel->remove($sock);
-	      $sock = undef;
+          # Check for the other sockets.
+          $sel->remove($sock);
+          $sock = undef;
       }
   } else {
       warn "timed out after $timeout seconds\n";
@@ -684,7 +685,7 @@ the source distribution.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
@@ -692,15 +693,15 @@ it and/or modify it under the same terms as Perl itself.
 =head1 AUTHOR INFORMATION
 
 Net::DNS is currently maintained by a group, led by:
-	Chris Reinhardt
-	ctriv@net-dns.org
+    Chris Reinhardt
+    ctriv@net-dns.org
 
 Net::DNS was created by:
-	Michael Fuhr
-	mike@fuhr.org
+    Michael Fuhr
+    mike@fuhr.org
 
 For more information see:
-	http://www.net-dns.org/
+    http://www.net-dns.org/
 
 =head1 SEE ALSO
  
