@@ -1,6 +1,6 @@
 package Net::DNS::Header;
 #
-# $Id: Header.pm,v 1.13 2003/09/19 18:28:24 ctriv Exp $
+# $Id: Header.pm,v 2.102 2004/05/05 20:35:43 ctriv Exp $
 #
 
 use strict;
@@ -10,7 +10,7 @@ use Net::DNS;
 
 use constant MAX_ID => 65535;
 
-$VERSION = (qw$Revision: 1.13 $)[1];
+$VERSION = (qw$Revision: 2.102 $)[1];
 
 =head1 NAME
 
@@ -58,7 +58,7 @@ sub new {
 	if (@_) {
 		my $data = shift;
 
-		if (length($$data) < &Net::DNS::HFIXEDSZ) {
+		if (length($$data) < Net::DNS::HFIXEDSZ()) {
 			return undef;
 		}
 
@@ -353,7 +353,7 @@ sub data {
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
