@@ -1,6 +1,6 @@
 package Net::DNS::Packet;
 #
-# $Id: Packet.pm,v 2.101 2004/01/04 04:12:57 ctriv Exp $
+# $Id: Packet.pm,v 2.104 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA @EXPORT_OK $VERSION $AUTOLOAD);
@@ -14,7 +14,7 @@ use Net::DNS;
 use Net::DNS::Question;
 use Net::DNS::RR;
 
-$VERSION = (qw$Revision: 2.101 $)[1];
+$VERSION = (qw$Revision: 2.104 $)[1];
 
 =head1 NAME
 
@@ -86,7 +86,7 @@ sub new {
 
 		$self{"header"}->print if $debug;
 
-		my $offset = &Net::DNS::HFIXEDSZ;
+		my $offset = Net::DNS::HFIXEDSZ();
 
 		#--------------------------------------------------------------
 		# Parse the question/zone section.
@@ -476,12 +476,12 @@ sub answersize {
 
 =head2 push
 
-    $packet->push("pre", $rr);
-    $packet->push("update", $rr);
-    $packet->push("additional", $rr);
+    $packet->push(pre        => $rr);
+    $packet->push(update     => $rr);
+    $packet->push(additional => $rr);
 
-    $packet->push("update", $rr1, $rr2, $rr3);
-    $packet->push("update", @rr);
+    $packet->push(update => $rr1, $rr2, $rr3);
+    $packet->push(update => @rr);
 
 Adds RRs to the specified section of the packet.
 
@@ -530,7 +530,42 @@ sub push {
 	}
 }
 
+=head2 unique_push
 
+    $packet->unique_push(pre        => $rr);
+    $packet->unique_push(update     => $rr);
+    $packet->unique_push(additional => $rr);
+
+    $packet->unique_push(update => $rr1, $rr2, $rr3);
+    $packet->unique_push(update => @rr);
+
+Adds RRs to the specified section of the packet provided that 
+the RRs do not already exist in the packet.
+
+=cut
+
+sub unique_push {
+	my ($self, $section, @rrs) = @_;
+	
+	foreach my $rr (@rrs) {
+		next if $self->{'seen'}->{$rr->string}++;
+
+		$self->push($section, $rr);
+	}
+}
+
+=head2 safe_push
+
+A deprecated name for C<unique_push()>.
+
+=cut
+
+sub safe_push {
+	carp('safe_push() is deprecated, use unique_push() instead,');
+	
+	goto &unique_push;
+}
+	
 
 =head2 pop
 
@@ -653,7 +688,7 @@ sub dn_expand_PP {
 	my $name = "";
 	my $len;
 	my $packetlen = length $$packet;
-	my $int16sz = &Net::DNS::INT16SZ;
+	my $int16sz = Net::DNS::INT16SZ();
 
 	# Debugging
 	#warn "USING PURE PERL dn_expand()\n";
@@ -842,10 +877,10 @@ sub parse_question {
 	return (undef, undef) unless defined $qname;
 
 	return (undef, undef)
-		if length($$data) < ($offset + 2 * &Net::DNS::INT16SZ);
+		if length($$data) < ($offset + 2 * Net::DNS::INT16SZ());
 
 	my ($qtype, $qclass) = unpack("\@$offset n2", $$data);
-	$offset += 2 * &Net::DNS::INT16SZ;
+	$offset += 2 * Net::DNS::INT16SZ();
 
 	$qtype  = Net::DNS::typesbyval($qtype);
 	$qclass = Net::DNS::classesbyval($qclass);
@@ -875,7 +910,7 @@ sub parse_rr {
 	return (undef, undef) unless defined $name;
 
 	return (undef, undef)
-		if length($$data) < ($offset + &Net::DNS::RRFIXEDSZ);
+		if length($$data) < ($offset + Net::DNS::RRFIXEDSZ());
 
 	my ($type, $class, $ttl, $rdlength) = unpack("\@$offset n2 N n", $$data);
 
@@ -888,7 +923,7 @@ sub parse_rr {
 	} 
 	# else just keep at its numerical value
 
-	$offset += &Net::DNS::RRFIXEDSZ;
+	$offset += Net::DNS::RRFIXEDSZ();
 
 	return (undef, undef)
 		if length($$data) < ($offset + $rdlength);
@@ -907,18 +942,13 @@ sub parse_rr {
 	return ($rrobj, $offset);
 }
 
-sub safe_push {
-	Carp::croak(<<END);
-Net::DNS::Packet::safe_push() has been removed.  The safe_push() method
-is only avalible from the Net::DNS::Update class.
-END
-}
+
 
 =head1 COPYRIGHT
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
