@@ -1,6 +1,6 @@
 package Net::DNS::Question;
 #
-# $Id: Question.pm,v 1.7 2003/09/03 04:41:50 ctriv Exp $
+# $Id: Question.pm,v 2.101 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw($VERSION $AUTOLOAD);
@@ -8,7 +8,7 @@ use vars qw($VERSION $AUTOLOAD);
 use Carp;
 use Net::DNS;
 
-$VERSION = (qw$Revision: 1.7 $)[1];
+$VERSION = (qw$Revision: 2.101 $)[1];
 
 =head1 NAME
 
@@ -50,6 +50,7 @@ sub new {
 	$qclass = defined($qclass) ? uc($qclass) : "ANY";
 
 	# Check if the caller has the type and class reversed.
+	# We are not that kind for unknown types.... :-)
 	if ((!exists $Net::DNS::typesbyname{$qtype} ||
 	     !exists $Net::DNS::classesbyname{$qclass})
 	    && exists $Net::DNS::classesbyname{$qtype}
@@ -170,8 +171,8 @@ sub data {
 
 	my $data = $packet->dn_comp($self->{"qname"}, $offset);
 
-	$data .= pack("n", $Net::DNS::typesbyname{uc($self->{"qtype"})});
-	$data .= pack("n", $Net::DNS::classesbyname{uc($self->{"qclass"})});
+	$data .= pack("n", Net::DNS::typesbyname(uc($self->{"qtype"})));
+	$data .= pack("n", Net::DNS::classesbyname(uc($self->{"qclass"})));
 	
 	return $data;
 }
@@ -180,7 +181,7 @@ sub data {
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
