@@ -1,6 +1,6 @@
 package Net::DNS::RR;
 #
-# $Id: RR.pm,v 2.102 2004/01/02 23:21:17 ctriv Exp $
+# $Id: RR.pm,v 2.108 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw($VERSION $AUTOLOAD);
@@ -9,7 +9,7 @@ use Carp;
 use Net::DNS;
 use Net::DNS::RR::Unknown;
 
-$VERSION = (qw$Revision: 2.102 $)[1];
+$VERSION = (qw$Revision: 2.108 $)[1];
 
 =head1 NAME
 
@@ -73,6 +73,7 @@ BEGIN {
 		TXT
 		X25
 		OPT
+		SSHFP
 	);
 
 	#  Only load DNSSEC if available
@@ -187,7 +188,7 @@ All names must be fully qualified.  The trailing dot (.) is optional.
  
  $rr = Net::DNS::RR->new(
 	 name => "foo.example.com",
-	 yype => "A",
+	 type => "A",
  );
 
 Returns an RR object of the appropriate type, or a C<Net::DNS::RR>
@@ -323,10 +324,8 @@ sub new_from_string {
 		'rdata'    => '',
 	};
 
-	
-	# $rdata!~/^\s*\\\#/ means that the rdata does not start with \# (rfc3597)
 
-	if ($RR{$rrtype} && $rdata !~ m/^\s*\\\#/ ) {
+	if ($RR{$rrtype} && $rdata !~ m/^\s*\\#/ ) {
 		my $subclass = $class->_get_subclass($rrtype);
 		
 		return $subclass->new_from_string($self, $rdata);
@@ -417,6 +416,9 @@ sub new_from_hash {
 			# documentation
 			return $subclass->new_from_hash($self);
 	    }
+	} elsif ($self->{'type'} =~ /TYPE\d+/) {
+		bless $self, 'Net::DNS::RR::Unknown';
+		return $self;
 	} else {
 	 	bless $self, $class;
 	 	return $self;
@@ -456,11 +458,13 @@ B<rdatastr> method to get the RR-specific data.
 sub string {
 	my $self = shift;
 
-	return $self->{'name'}  . ".\t" .
-	       $self->{'ttl'}   . "\t"  .
-	       $self->{'class'} . "\t"  .
-	       $self->{'type'}  . "\t"  .
-	       $self->rdatastr;
+	return join("\t",
+		"$self->{'name'}.",
+	 	 $self->{'ttl'},
+		 $self->{'class'},
+		 $self->{'type'},
+		 (defined $self->rdatastr and length $self->rdatastr) ? $self->rdatastr : '; no data',
+   );
 }
 
 =head2 rdatastr
@@ -475,8 +479,8 @@ to implement this method.
 sub rdatastr {
 	my $self = shift;
 	return exists $self->{'rdlength'}
-	       ? '; rdlength = ' . $self->{'rdlength'}
-	       : '; no data';
+	       ? "; rdlength = $self->{'rdlength'}"
+	       : '';
 }
 
 =head2 name
@@ -771,7 +775,7 @@ RR objects.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
