@@ -1,14 +1,12 @@
 package Net::DNS::RR::AAAA;
 #
-# $Id: AAAA.pm,v 1.4 2003/09/03 04:41:50 ctriv Exp $
+# $Id: AAAA.pm,v 2.103 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 1.4 $)[1];
+$VERSION = (qw$Revision: 2.103 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -60,9 +58,7 @@ sub new_from_string {
 sub rdatastr {
 	my $self = shift;
 
-	return exists $self->{"address"} && $self->{"address"}
-	       ? $self->{"address"}
-	       : "; no data";
+	return $self->{"address"} || '';
 }
 
 sub rr_rdata {
@@ -110,7 +106,7 @@ Section 2.2, Para 1).
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
