@@ -1,22 +1,19 @@
 package Net::DNS::RR::AFSDB;
 #
-# $Id: AFSDB.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+# $Id: AFSDB.pm,v 2.104 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS;
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.100 $)[1];
+$VERSION = (qw$Revision: 2.104 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
 		my ($subtype) = unpack("\@$offset n", $$data);
-		$offset += &Net::DNS::INT16SZ;
+		$offset += Net::DNS::INT16SZ();
 		my($hostname) = Net::DNS::Packet::dn_expand($data, $offset);
 		$self->{"subtype"} = $subtype;
 		$self->{"hostname"} = $hostname;
@@ -42,7 +39,7 @@ sub rdatastr {
 
 	return exists $self->{"subtype"}
 	       ? "$self->{subtype} $self->{hostname}."
-	       : "; no data";
+	       : '';
 }
 
 sub rr_rdata {
@@ -106,7 +103,7 @@ Returns the RR's hostname field.  See RFC 1183.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
