@@ -1,21 +1,18 @@
 package Net::DNS::RR::CNAME;
 #
-# $Id: CNAME.pm,v 1.5 2003/09/03 04:41:50 ctriv Exp $
+# $Id: CNAME.pm,v 2.103 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 1.5 $)[1];
+$VERSION = (qw$Revision: 2.103 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
-		my($cname) = Net::DNS::Packet::dn_expand($data, $offset);
-		$self->{"cname"} = $cname;
+		($self->{"cname"}) = Net::DNS::Packet::dn_expand($data, $offset);
 	}
 
 	return bless $self, $class;
@@ -35,9 +32,7 @@ sub new_from_string {
 sub rdatastr {
 	my $self = shift;
 
-	return exists $self->{"cname"} && $self->{"cname"}
-	       ? "$self->{cname}."
-	       : "; no data";
+	return $self->{"cname"} ? "$self->{cname}." : '';
 }
 
 sub rr_rdata {
@@ -85,7 +80,7 @@ Returns the RR's canonical name.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
