@@ -1,14 +1,12 @@
 package Net::DNS::RR::EID;
 #
-# $Id: EID.pm,v 1.3 2003/08/26 23:58:10 ctriv Exp $
+# $Id: EID.pm,v 2.102 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 1.3 $)[1];
+$VERSION = (qw$Revision: 2.102 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -46,9 +44,12 @@ Returns the record's data section as binary data.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-1998 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
+
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
