@@ -1,14 +1,12 @@
 package Net::DNS::RR::ISDN;
 #
-# $Id: ISDN.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+# $Id: ISDN.pm,v 2.103 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.100 $)[1];
+$VERSION = (qw$Revision: 2.103 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -59,9 +57,9 @@ sub new_from_string {
 sub rdatastr {
 	my $self = shift;
 
-	return exists $self->{"address"}
+	return $self->{"address"}
 	       ? qq("$self->{address}" "$self->{sa}")
-	       : "; no data";
+	       : '';
 }
 
 sub rr_rdata {
@@ -114,7 +112,7 @@ Returns the RR's subaddress field.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
