@@ -1,21 +1,18 @@
 package Net::DNS::RR::MB;
 #
-# $Id: MB.pm,v 1.4 2003/08/26 23:58:10 ctriv Exp $
+# $Id: MB.pm,v 2.103 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 1.4 $)[1];
+$VERSION = (qw$Revision: 2.103 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
-		my($madname) = Net::DNS::Packet::dn_expand($data, $offset);
-		$self->{"madname"} = $madname;
+		($self->{"madname"}) = Net::DNS::Packet::dn_expand($data, $offset);
 	}
 
 	return bless $self, $class;
@@ -35,9 +32,7 @@ sub new_from_string {
 sub rdatastr {
 	my $self = shift;
 
-	return exists $self->{"madname"}
-	       ? "$self->{madname}."
-	       : "; no data";
+	return $self->{"madname"} ? "$self->{madname}." : '';
 }
 
 sub rr_rdata {
@@ -59,6 +54,8 @@ sub _canonicalRdata {
 	}
 	return $rdata;
 }
+
+
 1;
 __END__
 
@@ -84,10 +81,12 @@ Returns the domain name of the host which has the specified mailbox.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-1998 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
 
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 =head1 SEE ALSO
 
 L<perl(1)>, L<Net::DNS>, L<Net::DNS::Resolver>, L<Net::DNS::Packet>,
