@@ -1,21 +1,18 @@
 package Net::DNS::RR::MR;
 #
-# $Id: MR.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+# $Id: MR.pm,v 2.103 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.100 $)[1];
+$VERSION = (qw$Revision: 2.103 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
-		my($newname) = Net::DNS::Packet::dn_expand($data, $offset);
-		$self->{"newname"} = $newname;
+		($self->{"newname"}) = Net::DNS::Packet::dn_expand($data, $offset);
 	}
 
 	return bless $self, $class;
@@ -35,9 +32,7 @@ sub new_from_string {
 sub rdatastr {
 	my $self = shift;
 
-	return exists $self->{"newname"}
-	       ? "$self->{newname}."
-	       : "; no data";
+	return $self->{"newname"} ? "$self->{newname}." : '';
 }
 
 sub rr_rdata {
@@ -89,7 +84,7 @@ Returns the RR's new name field.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
