@@ -1,26 +1,22 @@
 package Net::DNS::RR::MX;
 #
-# $Id: MX.pm,v 1.5 2003/09/03 04:41:51 ctriv Exp $
+# $Id: MX.pm,v 2.105 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS;
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 1.5 $)[1];
+$VERSION = (qw$Revision: 2.105 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
-		my ($preference) = unpack("\@$offset n", $$data);
-		$offset += &Net::DNS::INT16SZ;
-		my ($exchange) = Net::DNS::Packet::dn_expand($data, $offset);
-
-		$self->{"preference"} = $preference;
-		$self->{"exchange"} = $exchange;
+		($self->{"preference"}) = unpack("\@$offset n", $$data);
+		
+		$offset += Net::DNS::INT16SZ();
+		
+		($self->{"exchange"}) = Net::DNS::Packet::dn_expand($data, $offset);
 	}
 
 	return bless $self, $class;
@@ -41,9 +37,9 @@ sub new_from_string {
 sub rdatastr {
 	my $self = shift;
 
-	return exists $self->{"preference"}
+	return defined $self->{"preference"}
 	       ? "$self->{preference} $self->{exchange}."
-	       : "; no data";
+	       : '';
 }
 
 sub rr_rdata {
@@ -105,7 +101,7 @@ Returns name of this mail exchange.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
