@@ -1,25 +1,22 @@
 package Net::DNS::RR::NAPTR;
 #
-# $Id: NAPTR.pm,v 2.101 2004/01/04 04:31:10 ctriv Exp $
+# $Id: NAPTR.pm,v 2.104 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS;
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.101 $)[1];
+$VERSION = (qw$Revision: 2.104 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
 		($self->{"order"} ) = unpack("\@$offset n", $$data);
-		$offset += &Net::DNS::INT16SZ;
+		$offset += Net::DNS::INT16SZ();
 		
 		($self->{"preference"}) = unpack("\@$offset n", $$data);
-		$offset += &Net::DNS::INT16SZ;
+		$offset += Net::DNS::INT16SZ();
 		
 		my ($len) = unpack("\@$offset C", $$data);
 		++$offset;
@@ -164,7 +161,7 @@ Returns the replacement field.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
