@@ -1,31 +1,22 @@
 package Net::DNS::RR::PX;
 #
-# $Id: PX.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+# $Id: PX.pm,v 2.104 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS;
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.100 $)[1];
+$VERSION = (qw$Revision: 2.104 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
-		my ($preference, $map822, $mapx400);
+		($self->{"preference"}) = unpack("\@$offset n", $$data);
+		$offset += Net::DNS::INT16SZ();
 
-		($preference) = unpack("\@$offset n", $$data);
-		$offset += &Net::DNS::INT16SZ;
-
-		($map822,  $offset) = Net::DNS::Packet::dn_expand($data, $offset);
-		($mapx400, $offset) = Net::DNS::Packet::dn_expand($data, $offset);
-
-		$self->{"preference"} = $preference;
-		$self->{"map822"}     = $map822;
-		$self->{"mapx400"}    = $mapx400;
+		($self->{"map822"},  $offset) = Net::DNS::Packet::dn_expand($data, $offset);
+		($self->{"mapx400"}, $offset) = Net::DNS::Packet::dn_expand($data, $offset);
 	}
 
 	return bless $self, $class;
@@ -48,9 +39,9 @@ sub new_from_string {
 sub rdatastr {
 	my $self = shift;
 
-	return exists $self->{"preference"}
+	return $self->{"preference"}
 	       ? "$self->{preference} $self->{map822}. $self->{mapx400}."
-	       : "; no data";
+	       : '';
 }
 
 sub rr_rdata {
@@ -71,26 +62,20 @@ sub rr_rdata {
 }
 
 
-
-
-
 sub _canonicalRdata {
 	my ($self) = shift;
 	my $rdata = "";
 
 	if (exists $self->{"preference"}) {
 		$rdata .= pack("n", $self->{"preference"});
-
-		$rdata .= $self->_name2wire($self->{"map822"});
-					   
-
+		$rdata .= $self->_name2wire($self->{"map822"});					   
 		$rdata .= $self->_name2wire($self->{"mapx400"});
-
 	}
 
 	return $rdata;
 }
 
+
 1;
 __END__
 
@@ -130,7 +115,7 @@ Returns the X.400 part of the RFC1327 mapping information.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
