@@ -1,25 +1,21 @@
 package Net::DNS::RR::RT;
 #
-# $Id: RT.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+# $Id: RT.pm,v 2.104 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS;
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.100 $)[1];
+$VERSION = (qw$Revision: 2.104 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
-		my ($preference) = unpack("\@$offset n", $$data);
-		$offset += &Net::DNS::INT16SZ;
-		my ($intermediate) = Net::DNS::Packet::dn_expand($data, $offset);
-		$self->{"preference"} = $preference;
-		$self->{"intermediate"} = $intermediate;
+		($self->{"preference"})   = unpack("\@$offset n", $$data);
+		$offset += Net::DNS::INT16SZ();
+		
+		($self->{"intermediate"}) = Net::DNS::Packet::dn_expand($data, $offset);
 	}
 
 	return bless $self, $class;
@@ -40,9 +36,9 @@ sub new_from_string {
 sub rdatastr {
 	my $self = shift;
 
-	return exists $self->{"preference"}
+	return $self->{"preference"}
 	       ? "$self->{preference} $self->{intermediate}."
-	       : "; no data";
+	       : '';
 }
 
 sub rr_rdata {
@@ -57,6 +53,7 @@ sub rr_rdata {
 
 	return $rdata;
 }
+
 sub _canonicalRdata {
 	my ($self, $packet, $offset) = @_;
 	my $rdata = "";
@@ -64,11 +61,12 @@ sub _canonicalRdata {
 	if (exists $self->{"preference"}) {
 		$rdata .= pack("n", $self->{"preference"});
 		$rdata .= $self->_name2wire($self->{"intermediate"});
-	    }
+	}
 
 	return $rdata;
 }
 
+
 1;
 __END__
 
@@ -102,7 +100,7 @@ Returns the domain name of the intermediate host.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
