@@ -1,24 +1,21 @@
 package Net::DNS::RR::SRV;
 #
-# $Id: SRV.pm,v 2.101 2004/01/04 04:31:11 ctriv Exp $
+# $Id: SRV.pm,v 2.105 2004/05/05 20:36:00 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS;
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.101 $)[1];
+$VERSION = (qw$Revision: 2.105 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
-	if ($self->{"rdlength"} > 0) {
+	if ($self->{'rdlength'} > 0) {
 		@{$self}{qw(priority weight port)} = unpack("\@$offset n3", $$data);
-		$offset += 3 * &Net::DNS::INT16SZ;
+		$offset += 3 * Net::DNS::INT16SZ();
 		
-		($self->{"target"}) = Net::DNS::Packet::dn_expand($data, $offset);
+		($self->{'target'}) = Net::DNS::Packet::dn_expand($data, $offset);
 	}
 
 	return bless $self, $class;
@@ -28,11 +25,9 @@ sub new_from_string {
 	my ($class, $self, $string) = @_;
 
 	if ($string && ($string =~ /^(\d+)\s+(\d+)\s+(\d+)\s+(\S+)$/)) {
-		$self->{"priority"} = $1;
-		$self->{"weight"}   = $2;
-		$self->{"port"}     = $3;
-		$self->{"target"}   = $4;
-		$self->{"target"}   =~ s/\.+$//;
+		@{$self}{qw(priority weight port target)} = ($1, $2, $3, $4);
+
+		$self->{'target'} =~ s/\.+$//;
 	}
 
 	return bless $self, $class;
@@ -42,7 +37,7 @@ sub rdatastr {
 	my $self = shift;
 	my $rdatastr;
 
-	if ($self->{"priority"}) {
+	if (exists $self->{'priority'}) {
 		$rdatastr = join(' ', @{$self}{qw(priority weight port target)});
 	} else {
 		$rdatastr = '';
@@ -53,11 +48,11 @@ sub rdatastr {
 
 sub rr_rdata {
 	my ($self, $packet, $offset) = @_;
-	my $rdata = "";
+	my $rdata = '';
 
-	if (exists $self->{"priority"}) {
-		$rdata .= pack("n3", @{$self}{qw(priority weight port)});
-		$rdata .= $packet->dn_comp($self->{"target"}, $offset + length $rdata);
+	if (exists $self->{'priority'}) {
+		$rdata .= pack('n3', @{$self}{qw(priority weight port)});
+		$rdata .= $packet->dn_comp($self->{'target'}, $offset + length $rdata);
 	}
 
 	return $rdata;
@@ -68,9 +63,9 @@ sub _canonicalRdata {
 	my $self  = shift;
 	my $rdata = '';
 	
-	if (exists $self->{"priority"}) {
-		$rdata .= pack("n3", @{$self}{qw(priority weight port)});
-		$rdata .= $self->name_2wire($self->{"target"});
+	if (exists $self->{'priority'}) {
+		$rdata .= pack('n3', @{$self}{qw(priority weight port)});
+		$rdata .= $self->name_2wire($self->{'target'});
 	}
 
 	return $rdata;
@@ -121,7 +116,7 @@ Returns the target host.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
