@@ -1,16 +1,15 @@
 package Net::DNS::RR::TKEY;
 #
-# $Id: TKEY.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+# $Id: TKEY.pm,v 2.103 2004/05/04 23:16:18 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS::Packet;
 use Digest::HMAC_MD5;
 use MIME::Base64;
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.100 $)[1];
+$VERSION = (qw$Revision: 2.103 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -18,30 +17,22 @@ sub new {
 	# if we have some data then we are parsing an incoming TKEY packet
 	# see RFC2930 for the packet format
 	if ($self->{"rdlength"} > 0) {
-		my $alg;
-		($alg, $offset) = Net::DNS::Packet::dn_expand($data, $offset);
-		$self->{"algorithm"} = $alg;
+		($self->{"algorithm"}, $offset) = Net::DNS::Packet::dn_expand($data, $offset);
 
-		my ($inception, $expiration) = unpack("\@$offset NN", $$data);
-		$self->{"inception"} = $inception;
-		$self->{"expiration"} = $expiration;
-		$offset += &Net::DNS::INT32SZ + &Net::DNS::INT32SZ;
+		@{$self}{qw(inception expiration)} = unpack("\@$offset NN", $$data);
+		$offset += Net::DNS::INT32SZ() + Net::DNS::INT32SZ();
 
-		my ($mode, $error) = unpack("\@$offset nn", $$data);
-		$self->{"mode"} = $mode;
-		$self->{"error"} = $error;
-		$offset += &Net::DNS::INT16SZ + &Net::DNS::INT16SZ;
+		@{$self}{qw(inception expiration)} = unpack("\@$offset nn", $$data);
+		$offset += Net::DNS::INT16SZ() + Net::DNS::INT16SZ();
 
 		my ($key_len) = unpack("\@$offset n", $$data);
-		$offset += &Net::DNS::INT16SZ;
-		my $key = substr($$data, $offset, $key_len);
-		$self->{"key"} = $key;
+		$offset += Net::DNS::INT16SZ();
+		$self->{"key"} = substr($$data, $offset, $key_len);
 		$offset += $key_len;
 
 		my ($other_len) = unpack("\@$offset n", $$data);
-		$offset += &Net::DNS::INT16SZ;
-		my $otherdata = substr($$data, $offset, $other_len);
-		$self->{"other_data"} = $otherdata;
+		$offset += Net::DNS::INT16SZ();
+		$self->{"other_data"} = substr($$data, $offset, $other_len);
 		$offset += $other_len;
 	}
 
@@ -92,9 +83,8 @@ sub rdatastr {
 		if ($self->{"other_len"} && defined($self->{"other_data"})) {
 			$rdatastr .= " $self->{other_data}";
 		}
-	}
-	else {
-		$rdatastr = "; no data";
+	} else {
+		$rdatastr = '';
 	}
 
 	return $rdatastr;
