@@ -1,11 +1,10 @@
 package Net::DNS::RR::TSIG;
 #
-# $Id: TSIG.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+# $Id: TSIG.pm,v 2.104 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS::Packet;
 use Digest::HMAC_MD5;
 use MIME::Base64;
 
@@ -13,7 +12,7 @@ use constant DEFAULT_ALGORITHM => "HMAC-MD5.SIG-ALG.REG.INT";
 use constant DEFAULT_FUDGE     => 300;
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.100 $)[1];
+$VERSION = (qw$Revision: 2.104 $)[1];
 
 # a signing function for the HMAC-MD5 algorithm. This can be overridden using
 # the sign_func element
@@ -33,31 +32,22 @@ sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
-		my $alg;
-		($alg, $offset) = Net::DNS::Packet::dn_expand($data, $offset);
-		$self->{"algorithm"} = $alg;
+		($self->{"algorithm"}, $offset) = Net::DNS::Packet::dn_expand($data, $offset);
 
 		my ($time_high, $time_low) = unpack("\@$offset nN", $$data);
 		$self->{"time_signed"} = $time_low;	# bug
-		$offset += &Net::DNS::INT16SZ + &Net::DNS::INT32SZ;
+		$offset += Net::DNS::INT16SZ() + Net::DNS::INT32SZ();
 
-		my ($fudge, $macsize) = unpack("\@$offset nn", $$data);
-		$self->{"fudge"} = $fudge;
-		$self->{"mac_size"} = $macsize;
-		$offset += &Net::DNS::INT16SZ + &Net::DNS::INT16SZ;
+		@{$self}{qw(fudge mac_size)} = unpack("\@$offset nn", $$data);
+		$offset += Net::DNS::INT16SZ() + Net::DNS::INT16SZ();
 
-		my $mac = substr($$data, $offset, $macsize);
-		$self->{"mac"} = $mac;
-		$offset += $macsize;
+		$self->{"mac"} = substr($$data, $offset, $self->{'mac_size'});
+		$offset += $self->{'mac_size'};
 
-		my ($oid, $error, $olen) = unpack("\@$offset nnn", $$data);
-		$self->{"original_id"} = $oid;
-		$self->{"error"} = $error;
-		$self->{"other_len"} = $olen;
-		$offset += &Net::DNS::INT16SZ + &Net::DNS::INT16SZ
-                        +  &Net::DNS::INT16SZ;
+		@{$self}{qw(original_id error other_len)} = unpack("\@$offset nnn", $$data);
+		$offset += Net::DNS::INT16SZ() * 3;
 
-		my $odata = substr($$data, $offset, $olen);
+		my $odata = substr($$data, $offset, $self->{'other_len'});
 		my ($odata_high, $odata_low) = unpack("nN", $odata);
 		$self->{"other_data"} = $odata_low;
 	}
@@ -126,9 +116,8 @@ sub rdatastr {
 		if ($self->{"other_len"} && defined($self->{"other_data"})) {
 			$rdatastr .= " $self->{other_data}";
 		}
-	}
-	else {
-		$rdatastr = "; no data";
+	} else {
+		$rdatastr = "";
 	}
 
 	return $rdatastr;
@@ -339,7 +328,7 @@ appropriate sign_func.
 
 Copyright (c) 2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
