@@ -1,20 +1,20 @@
 package Net::DNS::Resolver;
 #
-# $Id: Resolver.pm,v 1.43 2003/12/01 04:33:50 ctriv Exp $
+# $Id: Resolver.pm,v 2.105 2004/05/05 20:35:43 ctriv Exp $
 #
 
 use strict;
 use vars qw($VERSION @ISA);
 
-$VERSION = (qw$Revision: 1.43 $)[1];
+$VERSION = (qw$Revision: 2.105 $)[1];
 
 BEGIN {
 	if ($^O eq 'MSWin32') {
 		require Net::DNS::Resolver::Win32;
 		@ISA = qw(Net::DNS::Resolver::Win32);
 	} elsif ($^O eq 'cygwin') {
-		 require Net::DNS::Resolver::Cygwin;
-		 @ISA = qw(Net::DNS::Resolver::Cygwin);
+		require Net::DNS::Resolver::Cygwin;
+		@ISA = qw(Net::DNS::Resolver::Cygwin);
 	} else {   
 		require Net::DNS::Resolver::UNIX;
 		@ISA = qw(Net::DNS::Resolver::UNIX);
@@ -74,7 +74,7 @@ recursion is desired, etc.
   	debug       => 1,
   );
 
-Returns a resolver object.  If given no argurments, C<new()> returns an
+Returns a resolver object.  If given no arguments, C<new()> returns an
 object configured to your system's defaults.  On UNIX systems the 
 defaults are read from the following files, in the order indicated:
 
@@ -174,58 +174,6 @@ An array reference of domains.
 For more information on any of these options, please consult the method
 of the same name.
 
-=head2 print
-
-    $res->print;
-
-Prints the resolver state on the standard output.
-
-=head2 string
-
-    print $res->string;
-
-Returns a string representation of the resolver state.
-
-=head2 searchlist
-
-    @searchlist = $res->searchlist;
-    $res->searchlist('example.com', 'a.example.com', 'b.example.com');
-
-Gets or sets the resolver search list.
-
-=head2 nameservers
-
-    @nameservers = $res->nameservers;
-    $res->nameservers('192.168.1.1', '192.168.2.2', '192.168.3.3');
-
-Gets or sets the nameservers to be queried.
-
-=head2 port
-
-    print 'sending queries to port ', $res->port, "\n";
-    $res->port(9732);
-
-Gets or sets the port to which we send queries.  This can be useful
-for testing a nameserver running on a non-standard port.  The
-default is port 53.
-
-=head2 srcport
-
-    print 'sending queries from port ', $res->srcport, "\n";
-    $res->srcport(5353);
-
-Gets or sets the port from which we send queries.  The default is 0,
-meaning any port.
-
-=head2 srcaddr
-
-    print 'sending queries from address ', $res->srcaddr, "\n";
-    $res->srcaddr('192.168.1.1');
-
-Gets or sets the source address from which we send queries.  Convenient
-for forcing queries out a specific interfaces on a multi-homed host.
-The default is 0.0.0.0, meaning any local address.
-
 =head2 search
 
     $packet = $res->search('mailhost');
@@ -275,7 +223,7 @@ applied.  If the name doesn't contain any dots and B<defnames>
 is true then the default domain will be appended.
 
 The record type and class can be omitted; they default to A and
-IN.  If the name looks like an IP address (4 dot-separated numbers),
+IN.  If the name looks like an IP address (IPv4 or IPv6),
 then an appropriate PTR query will be performed.
 
 Returns a C<Net::DNS::Packet> object, or C<undef> if no answers
@@ -293,7 +241,7 @@ nor the default domain will be appended.
 
 The argument list can be either a C<Net::DNS::Packet> object or a list
 of strings.  The record type and class can be omitted; they default to
-A and IN.  If the name looks like an IP address (4 dot-separated numbers),
+A and IN.  If the name looks like an IP address (Ipv4 or IPv6),
 then an appropriate PTR query will be performed.
 
 Returns a C<Net::DNS::Packet> object whether there were any answers or not.
@@ -301,6 +249,122 @@ Use C<< $packet->header->ancount >> or C<< $packet->answer >> to find out
 if there were any records in the answer section.  Returns C<undef> if there
 was an error.
 
+=head2 axfr
+
+    @zone = $res->axfr;
+    @zone = $res->axfr('example.com');
+    @zone = $res->axfr('passwd.example.com', 'HS');
+
+Performs a zone transfer from the first nameserver listed in C<nameservers>.
+If the zone is omitted, it defaults to the first zone listed in the resolver's
+search list.  If the class is omitted, it defaults to IN.
+
+Returns a list of C<Net::DNS::RR> objects, or C<undef> if the zone
+transfer failed.
+
+The redundant SOA record that terminates the zone transfer is not
+returned to the caller.
+
+See also L</axfr_start> and L</axfr_next>.
+
+Here's an example that uses a timeout:
+
+    $res->tcp_timeout(10);
+    my @zone = $res->axfr('example.com');
+
+    if (@zone) {
+        foreach my $rr (@zone) {
+            $rr->print;
+        }
+    } else {
+        print 'Zone transfer failed: ', $res->errorstring, "\n";
+    }
+
+=head2 axfr_start
+
+    $res->axfr_start;
+    $res->axfr_start('example.com');
+    $res->axfr_start('example.com', 'HS');
+
+Starts a zone transfer from the first nameserver listed in C<nameservers>.
+If the zone is omitted, it defaults to the first zone listed in the resolver's
+search list.  If the class is omitted, it defaults to IN.
+
+B<IMPORTANT>:
+
+This method currently returns the C<IO::Socket::INET> object that will
+be used for reading, or C<undef> on error.  DO NOT DEPEND ON C<axfr_next()>
+returning a socket object.  THIS WILL CHANGE in future releases.
+
+Use C<axfr_next> to read the zone records one at a time.
+
+=head2 axfr_next
+
+    $res->axfr_start('example.com');
+
+    while (my $rr = $res->axfr_next) {
+	    $rr->print;
+    }
+
+Reads records from a zone transfer one at a time.
+
+Returns C<undef> at the end of the zone transfer.  The redundant
+SOA record that terminates the zone transfer is not returned.
+
+See also L</axfr>.
+
+=head2 nameservers
+
+    @nameservers = $res->nameservers;
+    $res->nameservers('192.168.1.1', '192.168.2.2', '192.168.3.3');
+
+Gets or sets the nameservers to be queried.
+
+=head2 print
+
+    $res->print;
+
+Prints the resolver state on the standard output.
+
+=head2 string
+
+    print $res->string;
+
+Returns a string representation of the resolver state.
+
+=head2 searchlist
+
+    @searchlist = $res->searchlist;
+    $res->searchlist('example.com', 'a.example.com', 'b.example.com');
+
+Gets or sets the resolver search list.
+
+=head2 port
+
+    print 'sending queries to port ', $res->port, "\n";
+    $res->port(9732);
+
+Gets or sets the port to which we send queries.  This can be useful
+for testing a nameserver running on a non-standard port.  The
+default is port 53.
+
+=head2 srcport
+
+    print 'sending queries from port ', $res->srcport, "\n";
+    $res->srcport(5353);
+
+Gets or sets the port from which we send queries.  The default is 0,
+meaning any port.
+
+=head2 srcaddr
+
+    print 'sending queries from address ', $res->srcaddr, "\n";
+    $res->srcaddr('192.168.1.1');
+
+Gets or sets the source address from which we send queries.  Convenient
+for forcing queries out a specific interfaces on a multi-homed host.
+The default is 0.0.0.0, meaning any local address.
+
 =head2 bgsend
 
     $socket = $res->bgsend($packet_object);
@@ -340,7 +404,7 @@ The programmer should close or destroy the socket object after reading it.
 
     $socket = $res->bgsend('foo.example.com');
     until ($res->bgisready($socket)) {
-	# do some other processing
+        # do some other processing
     }
     $packet = $res->bgread($socket);
     $socket = undef;
@@ -350,69 +414,9 @@ an C<IO::Socket> object returned by C<< $res->bgsend >>.
 
 Returns true if the socket is ready, false if not.
 
-=head2 axfr
-
-    @zone = $res->axfr;
-    @zone = $res->axfr('example.com');
-    @zone = $res->axfr('passwd.example.com', 'HS');
-
-Performs a zone transfer from the first nameserver listed in C<nameservers>.
-If the zone is omitted, it defaults to the first zone listed in the resolver's
-search list.  If the class is omitted, it defaults to IN.
-
-Returns a list of C<Net::DNS::RR> objects, or C<undef> if the zone
-transfer failed.
-
-The redundant SOA record that terminates the zone transfer is not
-returned to the caller.
-
-See also L</axfr_start> and L</axfr_next>.
-
-Here's an example that uses a timeout:
-
-    $res->tcp_timeout(10);
-    @zone = $res->axfr('example.com');
-    if (@zone) {
-        foreach $rr (@zone) {
-            $rr->print;
-        }
-    }
-    else {
-        print 'Zone transfer failed: ', $res->errorstring, "\n";
-    }
-
-=head2 axfr_start
-
-    $res->axfr_start;
-    $res->axfr_start('example.com');
-    $res->axfr_start('example.com', 'HS');
-
-Starts a zone transfer from the first nameserver listed in C<nameservers>.
-If the zone is omitted, it defaults to the first zone listed in the resolver's
-search list.  If the class is omitted, it defaults to IN.
-
-Returns the C<IO::Socket::INET> object that will be used for reading, or
-C<undef> on error.
-
-Use C<axfr_next> to read the zone records one at a time.
-
-=head2 axfr_next
-
-    $res->axfr_start('example.com');
-    while ($rr = $res->axfr_next) {
-	    $rr->print;
-    }
-
-Reads records from a zone transfer one at a time.
-
-Returns C<undef> at the end of the zone transfer.  The redundant
-SOA record that terminates the zone transfer is not returned.
-
-See also L</axfr>.
-
 =head2 tsig
 
-    $tsig = $res->tsig;
+    my $tsig = $res->tsig;
 
     $res->tsig(Net::DNS::RR->new("$key_name TSIG $key"));
 
@@ -592,10 +596,10 @@ to 1.
     $res->udppacketsize(2048);
 
 udppacketsize will set or get the packet size. If set to a value greater than 
-&Net::DNS::PACKETSZ an EDNS extention will be added indicating suppport for MTU path 
+Net::DNS::PACKETSZ() an EDNS extension will be added indicating suppport for MTU path 
 recovery.
 
-Default udppacketsize is &Net::DNS::PACKETSZ (512)
+Default udppacketsize is Net::DNS::PACKETSZ() (512)
 
 =head1 CUSTOMIZING
 
@@ -678,7 +682,7 @@ No validation of server replies is performed.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
