@@ -1,6 +1,6 @@
 package Net::DNS::Resolver::Base;
 #
-# $Id: Base.pm,v 2.105 2004/02/10 00:27:47 ctriv Exp $
+# $Id: Base.pm,v 2.109 2004/05/05 20:35:43 ctriv Exp $
 #
 
 use strict;
@@ -19,7 +19,7 @@ use IO::Select;
 use Net::DNS;
 use Net::DNS::Packet;
 
-$VERSION = (qw$Revision: 2.105 $)[1];
+$VERSION = (qw$Revision: 2.109 $)[1];
 
 #
 # Set up a closure to be our class data.
@@ -119,7 +119,11 @@ sub _process_args {
 				UNIVERSAL::isa($args{$attr}, 'ARRAY');
 		}
 		
-		$self->{$attr} = $args{$attr};
+		if ($attr eq 'nameservers') {
+			$self->nameservers(@{$args{$attr}});
+		} else {
+			$self->{$attr} = $args{$attr};
+		}
 	}
 }
 			
@@ -303,14 +307,14 @@ sub cname_addr {
 }
 
 
-# if ($self->{"udppacketsize"}  > &Net::DNS::PACKETSZ 
+# if ($self->{"udppacketsize"}  > Net::DNS::PACKETSZ() 
 # then we use EDNS and $self->{"udppacketsize"} 
 # should be taken as the maximum packet_data length
 sub _packetsz {
 	my ($self) = @_;
 
-	return $self->{"udppacketsize"} > &Net::DNS::PACKETSZ ? 
-		   $self->{"udppacketsize"} : &Net::DNS::PACKETSZ; 
+	return $self->{"udppacketsize"} > Net::DNS::PACKETSZ() ? 
+		   $self->{"udppacketsize"} : Net::DNS::PACKETSZ(); 
 }
 
 sub _reset_errorstring {
@@ -325,8 +329,8 @@ sub search {
 	my ($name, $type, $class) = @_;
 	my $ans;
 
-	$type  = 'A'  unless defined($type);
-	$class = 'IN' unless defined($class);
+	$type  ||= 'A';
+	$class ||= 'IN';
 
 	# If the name looks like an IP address then do an appropriate
 	# PTR query.
@@ -334,6 +338,11 @@ sub search {
 		$name = "$4.$3.$2.$1.in-addr.arpa.";
 		$type = 'PTR';
 	}
+	
+	# pass IPv6 addresses right to query()
+	if (index($name, ':') > 0 and index($name, '.') < 0) {
+		return $self->query($name);
+	}
 
 	# If the name contains at least one dot then try it as is first.
 	if (index($name, '.') >= 0) {
@@ -368,8 +377,8 @@ sub search {
 sub query {
 	my ($self, $name, $type, $class) = @_;
 
-	$type  = 'A'  unless defined($type);
-	$class = 'IN' unless defined($class);
+	$type  ||= 'A';
+	$class ||= 'IN';
 
 	# If the name doesn't contain any dots then append the default domain.
 	if ((index($name, '.') < 0) && (index($name, ':') < 0) && $self->{'defnames'}) {
@@ -526,7 +535,7 @@ sub send_tcp {
 		my $sel = IO::Select->new($sock);
 
 		if ($sel->can_read($timeout)) {
-			my $buf = read_tcp($sock, &Net::DNS::INT16SZ, $self->{'debug'});
+			my $buf = read_tcp($sock, Net::DNS::INT16SZ(), $self->{'debug'});
 			next unless length($buf);
 			my ($len) = unpack('n', $buf);
 			next unless $len;
@@ -832,7 +841,7 @@ sub make_query_packet {
 				 
 	    $packet->push('additional', $optrr);
 	    
-	} elsif ($self->{'udppacketsize'} > &Net::DNS::PACKETSZ) {
+	} elsif ($self->{'udppacketsize'} > Net::DNS::PACKETSZ()) {
 	    print ";; Adding EDNS extention with UDP packetsize  $self->{'udppacketsize'}.\n" if $self->{'debug'};
 	    # RFC 3225
 	    my $optrr = Net::DNS::RR->new( 
@@ -988,7 +997,7 @@ sub axfr_next {
 			return wantarray ? (undef, $err) : undef;
 		}
 
-		my $buf = read_tcp($ready[0], &Net::DNS::INT16SZ, $self->{'debug'});
+		my $buf = read_tcp($ready[0], Net::DNS::INT16SZ(), $self->{'debug'});
 		unless (length $buf) {
 			$err = 'truncated zone transfer';
 			$self->errorstring($err);
@@ -1185,7 +1194,7 @@ for all your resolving needs.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
