@@ -1,6 +1,6 @@
 package Net::DNS::Resolver::Cygwin;
 #
-# $Id: Cygwin.pm,v 1.2 2003/12/01 11:46:17 ctriv Exp $
+# $Id: Cygwin.pm,v 2.103 2004/05/05 20:35:43 ctriv Exp $
 #
 
 use strict;
@@ -8,22 +8,22 @@ use vars qw(@ISA $VERSION);
 
 use Net::DNS::Resolver::Base ();
 
-@ISA     = qw(Net::DNS::Resolver::Base);
-$VERSION = (qw$Revision: 1.2 $)[1];
+@ISA	 = qw(Net::DNS::Resolver::Base);
+$VERSION = (qw$Revision: 2.103 $)[1];
 
 sub getregkey {
-    my $key   = $_[0] . $_[1];
-    my $value = '';
+	my $key	  = $_[0] . $_[1];
+	my $value = '';
 
-	local *LM;    
+	local *LM;	  
 
-    if (open(LM, "<$key")) {
-        $value = <LM>;
-        $value =~ s/\0+$//;
-        close(LM);
-    }
-    
-    return $value;
+	if (open(LM, "<$key")) {
+		$value = <LM>;
+		$value =~ s/\0+$//;
+		close(LM);
+	}
+	
+	return $value;
 }
 
 sub init {
@@ -34,10 +34,10 @@ sub init {
 	
 	my $root = '/proc/registry/HKEY_LOCAL_MACHINE/SYSTEM/CurrentControlSet/Services/Tcpip/Parameters/';
    
-    unless (-d $root) {
+	unless (-d $root) {
 		# Doesn't exist, maybe we are on 95/98/Me?
 		$root = '/proc/registry/HKEY_LOCAL_MACHINE/SYSTEM/CurrentControlSet/Services/VxD/MSTCP/';
-        -d $root || Carp::croak "can't read registry: $!";
+		-d $root || Carp::croak "can't read registry: $!";
 	}
 
 	# Best effort to find a useful domain name for the current host
@@ -49,19 +49,22 @@ sub init {
 	# also see below for domain name devolution if so configured
 	# (also remove any duplicates later)
 	my $searchlist = "$domain ";
-	$searchlist  .= getregkey($root, 'SearchList');
+	$searchlist	 .= getregkey($root, 'SearchList');
 	
 	# This is (probably) adequate on NT4
-	my $nameservers = getregkey($root, 'NameServer') || getregkey($root, 'DhcpNameServer');
+	my $nt4nameservers = getregkey($root, 'NameServer') || getregkey($root, 'DhcpNameServer');
+	my $nameservers = "";
 	#
 	# but on W2K/XP the registry layout is more advanced due to dynamically
 	# appearing connections. So we attempt to handle them, too...
 	# opt to silently fail if something isn't ok (maybe we're on NT4)
+    # If this doesn't fail override any NT4 style result we found, as it
+    # may be there but is not valid.
 	# drop any duplicates later
 	my $dnsadapters = $root . "DNSRegisteredAdapters/";
 	if (opendir(LM, $dnsadapters)) {
 		my @adapters = grep($_ ne "." && $_ ne "..", readdir(LM));
-        closedir(LM);
+		closedir(LM);
 		foreach my $adapter (@adapters) {
 			my $regadapter = $dnsadapters . $adapter . '/';
 			if (-e $regadapter) {
@@ -77,20 +80,23 @@ sub init {
 	my $interfaces = $root . "Interfaces/";
 	if (opendir(LM, $interfaces)) {
 		my @ifacelist = grep($_ ne "." && $_ ne "..", readdir(LM));
-        closedir(LM);
+		closedir(LM);
 		foreach my $iface (@ifacelist) {
 			my $regiface = $interfaces . $iface . '/';
 			if (opendir(LM, $regiface)) {
-                closedir(LM);
+				closedir(LM);
 				my $ns;
-                $ns = getregkey($regiface, "NameServer");
-				$nameservers .= " $ns" if $ns;
-                $ns = getregkey($regiface, "DhcpNameServer");
+				$ns = getregkey($regiface, "NameServer") ||
+					getregkey($regiface, "DhcpNameServer") || '';
 				$nameservers .= " $ns" if $ns;
 			}
 		}
 	}
 
+	if (!$nameservers) {
+		$nameservers = $nt4nameservers;
+	}
+
 	if ($domain) {
 		$defaults->{'domain'} = $domain;
 	}
@@ -107,9 +113,9 @@ sub init {
 				while ($entry =~ m#\..+\.#) {
 					$entry =~ s#^[^\.]+\.(.+)$#$1#;
 					$h{$entry} = $i++;
-					}
 				}
 			}
+		}
 		my @a;
 		$a[$h{$_}] = $_ foreach (keys %h);
 		$defaults->{'searchlist'} = \@a;
@@ -120,10 +126,10 @@ sub init {
 		my @a;
 		my %h;
 		foreach my $ns (split(m/[\s,]+/, $nameservers)) {
-			push @a, $ns unless $h{$ns};
+			push @a, $ns unless (!$ns || $h{$ns});
 			$h{$ns} = 1;
 		}
-		$defaults->{'nameservers'} = \@a;
+		$defaults->{'nameservers'} = [map { m/(.*)/ } @a];
 	}
 
 	$class->read_env;
@@ -158,7 +164,7 @@ for all your resolving needs.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
