@@ -1,6 +1,6 @@
 package Net::DNS::Update;
 #
-# $Id: Update.pm,v 2.101 2004/01/04 04:31:10 ctriv Exp $
+# $Id: Update.pm,v 2.103 2004/05/05 20:35:43 ctriv Exp $
 #
 use strict;
 use vars qw($VERSION @ISA);
@@ -8,7 +8,7 @@ use vars qw($VERSION @ISA);
 use Net::DNS;
 
 @ISA     = qw(Net::DNS::Packet);
-$VERSION = (qw$Revision: 2.101 $)[1];
+$VERSION = (qw$Revision: 2.103 $)[1];
 
 =head1 NAME
 
@@ -76,41 +76,6 @@ sub new {
 }
 
 
-=head2 safe_push
-
-    $update->safe_push(pre        => $rr);
-    $update->safe_push(update     => $rr);
-    $update->safe_push(additional => $rr);
-
-Adds unseen RRs to the specified section of the update. This is useful
-to insure that the udpates do not contain redundant RRs in any of the
-sections.
-
-=cut
-
-sub safe_push {
-	my ($self, $section, @rrs) = @_;
-	
-	foreach my $rr (@rrs) {
-		next if $self->{'seen'}->{$rr->string};
-		
-		$self->push($section, $rr);
-	}
-}
-
-
-# overload push to DTRT.  We don't need to worry about populating
-# seen inside of new() because you only can use safe_push with
-# an update object.
-
-sub push {
-	my ($self, $section, @rrs) = @_;
-	
-	$self->{'seen'}{$_->string}++ for @rrs;
-
-	return $self->SUPER::push($section, @rrs);
-}
-
 =head1 EXAMPLES
 
 The first example below shows a complete program; subsequent examples
@@ -216,7 +181,7 @@ production nameservers.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
